@@ -182,6 +182,18 @@ func (f *Client) Get(ctx context.Context, machineID string) (*api.Machine, error
 	return out, nil
 }
 
+func (f *Client) GetMany(ctx context.Context, machineIDs []string) ([]*api.Machine, error) {
+	machines := make([]*api.Machine, 0, len(machineIDs))
+	for _, id := range machineIDs {
+		m, err := f.Get(ctx, id)
+		if err != nil {
+			return machines, err
+		}
+		machines = append(machines, m)
+	}
+	return machines, nil
+}
+
 func (f *Client) List(ctx context.Context, state string) ([]*api.Machine, error) {
 	getEndpoint := ""
 
