@@ -158,7 +158,7 @@ func updateImageForNomad(ctx context.Context) error {
 		tb := render.NewTextBlock(ctx, fmt.Sprintf("Release command detected: %s\n", releaseCommand.Command))
 		tb.Done("This release will not be available until the release command succeeds.")
 
-		if err := watch.ReleaseCommand(ctx, releaseCommand.ID); err != nil {
+		if err := watch.ReleaseCommand(ctx, appName, releaseCommand.ID); err != nil {
 			return err
 		}
 
